.. py:function:: sf_transport_2_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_transport_2_e`
    c code signature: int gsl_sf_transport_2_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_transport_5(x [, ret])

    Wrapper for :c:func:`gsl_sf_transport_5`
    c code signature: double gsl_sf_transport_5(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_transport_5_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_transport_5_e`
    c code signature: int gsl_sf_transport_5_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_transport_3_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_transport_3_e`
    c code signature: int gsl_sf_transport_3_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_transport_2(x [, ret])

    Wrapper for :c:func:`gsl_sf_transport_2`
    c code signature: double gsl_sf_transport_2(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_transport_3(x [, ret])

    Wrapper for :c:func:`gsl_sf_transport_3`
    c code signature: double gsl_sf_transport_3(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_transport_4_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_transport_4_e`
    c code signature: int gsl_sf_transport_4_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_transport_4(x [, ret])

    Wrapper for :c:func:`gsl_sf_transport_4`
    c code signature: double gsl_sf_transport_4(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

